[MOAB-dev] r1331 - MOAB/trunk

dcthomp at mcs.anl.gov dcthomp at mcs.anl.gov
Wed Oct 24 14:41:42 CDT 2007


Author: dcthomp
Date: 2007-10-24 14:41:42 -0500 (Wed, 24 Oct 2007)
New Revision: 1331

Modified:
   MOAB/trunk/MBOrientedBox.cpp
   MOAB/trunk/MBOrientedBox.hpp
   MOAB/trunk/MBOrientedBoxTreeTool.cpp
   MOAB/trunk/configure.in
Log:
STYLE: s/covarience/covariance/g, whitespace cleanup


Modified: MOAB/trunk/MBOrientedBox.cpp
===================================================================
--- MOAB/trunk/MBOrientedBox.cpp	2007-10-24 19:38:38 UTC (rev 1330)
+++ MOAB/trunk/MBOrientedBox.cpp	2007-10-24 19:41:42 UTC (rev 1331)
@@ -300,7 +300,7 @@
   return box_from_axes( result, instance, vertices );
 }
 
-MBErrorCode MBOrientedBox::covarience_data_from_tris( CovarienceData& result,
+MBErrorCode MBOrientedBox::covariance_data_from_tris( CovarienceData& result,
                                                  MBInterface* instance,
                                                  const MBRange& elements )
 {
@@ -354,7 +354,7 @@
 {
     // Get orientation data from elements
   CovarienceData data;
-  MBErrorCode rval = covarience_data_from_tris( data, instance, elements );
+  MBErrorCode rval = covariance_data_from_tris( data, instance, elements );
   if (MB_SUCCESS != rval)
     return rval;
   
@@ -365,10 +365,10 @@
     return rval;
     
     // Calculate box given points and orientation data
-  return compute_from_covarience_data( result, instance, data, points );
+  return compute_from_covariance_data( result, instance, data, points );
 }
 
-MBErrorCode MBOrientedBox::compute_from_covarience_data(
+MBErrorCode MBOrientedBox::compute_from_covariance_data(
                                                 MBOrientedBox& result,
                                                 MBInterface* instance,
                                                 CovarienceData& data,
@@ -413,7 +413,7 @@
 #endif
 }
 
-MBErrorCode MBOrientedBox::compute_from_covarience_data( MBOrientedBox& result,
+MBErrorCode MBOrientedBox::compute_from_covariance_data( MBOrientedBox& result,
                                                 MBInterface* moab_instance,
                                                 const CovarienceData* data,
                                                 unsigned data_length,
@@ -427,7 +427,7 @@
     data_sum.area += data->area;
   }
     // Compute box from sum of structs
-  return compute_from_covarience_data( result, moab_instance, data_sum, vertices );
+  return compute_from_covariance_data( result, moab_instance, data_sum, vertices );
 }
 
 

Modified: MOAB/trunk/MBOrientedBox.hpp
===================================================================
--- MOAB/trunk/MBOrientedBoxTreeTool.cpp	2007-10-24 19:38:38 UTC (rev 1330)
+++ MOAB/trunk/MBOrientedBoxTreeTool.cpp	2007-10-24 19:41:42 UTC (rev 1331)
@@ -143,7 +143,7 @@
     data.push_back( SetData() );
     SetData& set_data = data.back();
     set_data.handle = *i;
-    rval = MBOrientedBox::covarience_data_from_tris( set_data.box_data, instance, elements );
+    rval = MBOrientedBox::covariance_data_from_tris( set_data.box_data, instance, elements );
     if (MB_SUCCESS != rval)
       return rval;
   }
@@ -342,7 +342,7 @@
     if (MB_SUCCESS != rval)
       return rval;
     
-    rval = MBOrientedBox::compute_from_covarience_data( box, instance, &data[0], data.size(), points );
+    rval = MBOrientedBox::compute_from_covariance_data( box, instance, &data[0], data.size(), points );
     if (MB_SUCCESS != rval)
       return rval;
   }

Modified: MOAB/trunk/configure.in
===================================================================
--- MOAB/trunk/configure.in	2007-10-24 19:38:38 UTC (rev 1330)
+++ MOAB/trunk/configure.in	2007-10-24 19:41:42 UTC (rev 1331)
@@ -562,9 +562,9 @@
   SNL_CHECK_LIB_LIST([vtkmetaio],     [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
   SNL_CHECK_LIB_LIST([vtkIO],         [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
   SNL_CHECK_LIB_LIST([vtkRendering],  [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
-  SNL_CHECK_LIB_LIST([vtkParallel],  [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
+  SNL_CHECK_LIB_LIST([vtkParallel],   [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
   SNL_CHECK_LIB_LIST([vtkHybrid],     [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
-  SNL_CHECK_LIB_LIST([QVTK],     [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
+  SNL_CHECK_LIB_LIST([QVTK],          [vtk_libs],[$vtk_libs_arg],[-L$VTK_LIB_DIR])
   
    # Make sure we found at least vtkCommon and vtkRendering
   if ! echo "x $vtk_libs" | grep lvtkCommon >/dev/null; then




More information about the moab-dev mailing list
--- MOAB/trunk/MBOrientedBox.hpp	2007-10-24 19:38:38 UTC (rev 1330)
+++ MOAB/trunk/MBOrientedBox.hpp	2007-10-24 19:41:42 UTC (rev 1331)
@@ -92,25 +92,25 @@
                                             const MBRange& elements );
 
     /** Structure to hold temporary accumulated triangle data for
      *  caculating box orietation.  See box_from_covarience_data
      *  to see how this is used to calculate the final covarience matrix
      *  and resulting box orientation.
      */
   struct CovarienceData {
-    MBMatrix3 matrix;    //!< Running sum for covarience matrix
+    MBMatrix3 matrix;    //!< Running sum for covariance matrix
     MBCartVect center;   //!< Sum of triangle centroids weighted by 2*triangle area
     double area;         //!< 2x the sum of the triangle areas
   };
   
     /** Calculate a CovarienceData struct from a list of triangles */
-  static MBErrorCode covarience_data_from_tris( CovarienceData& result,
+  static MBErrorCode covariance_data_from_tris( CovarienceData& result,
                                                 MBInterface* moab_instance,
                                                 const MBRange& elements );
   
     /** Calculate an MBOrientedBox given an arrray of CovarienceData and 
      *  the list  of vertices the box is to bound.
      */
-  static MBErrorCode compute_from_covarience_data( MBOrientedBox& result,
+  static MBErrorCode compute_from_covariance_data( MBOrientedBox& result,
                                           MBInterface* moab_instance,
                                           const CovarienceData* orient_array,
                                           unsigned orient_array_length,
@@ -145,7 +145,7 @@
     /** Calculate an MBOrientedBox given a CovarienceData struct and
      *  the list of points the box is to bound.
      */
-  static MBErrorCode compute_from_covarience_data( MBOrientedBox& result,
+  static MBErrorCode compute_from_covariance_data( MBOrientedBox& result,
                                           MBInterface* moab_instance,
                                           CovarienceData& orientation_data,
                                           const MBRange& vertices );
@@ -92,25 +92,25 @@
 
     /** Structure to hold temporary accumulated triangle data for
-     *  caculating box orietation.  See box_from_covarience_data
-     *  to see how this is used to calculate the final covarience matrix
+     *  caculating box orietation.  See box_from_covariance_data
+     *  to see how this is used to calculate the final covariance matrix
      *  and resulting box orientation.
      */

Modified: MOAB/trunk/MBOrientedBoxTreeTool.cpp
===================================================================